==> xtube_0.1.6-2.tar.gz: xtube-0.1.6/src/opt/usr/share/qmltube/qml/qmltube/scripts/xtube.js <==
/* Functions for access to adult content */

function xhamsterSearch(query, order) {
    /* Perform a search of xHamster */

    var searchOrder = "";
    if (order = qsTr("date")) {
        searchOrder = "da";
    }
    else if (order = qsTr("views")) {
        searchOrder = "vc";
    }
    else if (order = qsTr("rating")) {
        searchOrder = "rt";
    }

    var videoFeed = ("http://xhamster.com/search.php?q=" + query.replace(" ", "+") + "&s=" + searchOrder + "&page=1");
    loadXHamsterVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
}

function loadXHamsterVideos(feed, title) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "XHamsterListView.qml";
    loader.item.goToVideo.connect(loadXHamsterVideoInfo);
    loader.item.setVideoFeed(feed);
    notificationArea.addTitle(title);
    windowView.incrementCurrentIndex();
}

function loadXHamsterVideoInfo(video) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "XHamsterInfoView.qml";
    loader.item.goToVideo.connect(loadXHamsterVideoInfo);
    loader.item.authorClicked.connect(loadXHamsterUserVideos);
    loader.item.search.connect(xhamsterSearch);
    loader.item.setVideo(video);
    notificationArea.addTitle(qsTr("Video Info"));
    windowView.incrementCurrentIndex();
}

function loadXHamsterUserVideos(feed, username) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "XHamsterListView.qml";
    loader.item.goToVideo.connect(loadXHamsterVideoInfo);
    loader.item.setVideoFeed(feed);
    notificationArea.addTitle(username);
    windowView.incrementCurrentIndex();
}

function youjizzSearch(query, order) {
    /* Perform a search of YouJizz */

    var searchOrder = order;
    if ((order == qsTr("date")) || (order == qsTr("relevance"))) {
        searchOrder = "recent";
    }

    var videoFeed = ("http://youjizz.com/search/" + searchOrder + "_" + query.replace(" ", "-") + "-1.html");
    loadYouJizzVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
}

function loadYouJizzVideos(feed, title) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "YouJizzListView.qml";
    loader.item.goToVideo.connect(loadYouJizzVideoInfo);
    loader.item.setVideoFeed(feed);
    notificationArea.addTitle(title);
    windowView.incrementCurrentIndex();
}

function loadYouJizzVideoInfo(video) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "YouJizzInfoView.qml";
    loader.item.goToVideo.connect(loadYouJizzVideoInfo);
    loader.item.search.connect(youjizzSearch);
    loader.item.setVideo(video);
    notificationArea.addTitle(qsTr("Video Info"));
    windowView.incrementCurrentIndex();
}

==> xtube_0.3.0-1.tar.gz: xtube-0.3.0/src/opt/usr/share/qmltube/qml/qmltube/scripts/xtube.js <==
/* Functions for access to adult content */

function xhamsterSearch(query, order) {
    /* Perform a search of xHamster */

    var searchOrder = "";
    if (order = "date") {
        searchOrder = "da";
    }
    else if (order = "views") {
        searchOrder = "vc";
    }
    else if (order = "rating") {
        searchOrder = "rt";
    }

    var videoFeed = ("http://xhamster.com/search.php?q=" + query.replace(" ", "+") + "&s=" + searchOrder + "&page=1");
    loadXHamsterVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
}

function loadXHamsterVideos(feed, title) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.opacity = 0;
    loader.source = "XHamsterListView.qml";
    loader.item.goToVideo.connect(loadXHamsterVideoInfo);
    loader.item.playVideos.connect(loadPlaybackView);
    loader.item.setVideoFeed(feed);
    notificationArea.addTitle(title);
    windowView.incrementCurrentIndex();
}

function loadXHamsterVideoInfo(video) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.opacity = 0;
    loader.source = "XHamsterInfoView.qml";
    loader.item.goToVideo.connect(loadXHamsterVideoInfo);
    loader.item.playVideo.connect(loadPlaybackView);
    loader.item.authorClicked.connect(loadXHamsterUserVideos);
    loader.item.search.connect(xhamsterSearch);
    loader.item.setVideo(video);
    notificationArea.addTitle(qsTr("Video Info"));
    windowView.incrementCurrentIndex();
}

function loadXHamsterUserVideos(feed, username) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.opacity = 0;
    loader.source = "XHamsterListView.qml";
    loader.item.goToVideo.connect(loadXHamsterVideoInfo);
    loader.item.playVideos.connect(loadPlaybackView);
    loader.item.setVideoFeed(feed);
    notificationArea.addTitle(username);
    windowView.incrementCurrentIndex();
}

function youjizzSearch(query, order) {
    /* Perform a search of YouJizz */

    var searchOrder = order;
    if ((order == "date") || (order == "relevance")) {
        searchOrder = "recent";
    }

    var videoFeed = ("http://youjizz.com/search/" + searchOrder + "_" + query.replace(" ", "-") + "-1.html");
    loadYouJizzVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
}

function loadYouJizzVideos(feed, title) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.opacity = 0;
    loader.source = "YouJizzListView.qml";
    loader.item.goToVideo.connect(loadYouJizzVideoInfo);
    loader.item.playVideos.connect(loadPlaybackView);
    loader.item.setVideoFeed(feed);
    notificationArea.addTitle(title);
    windowView.incrementCurrentIndex();
}

function loadYouJizzVideoInfo(video) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.opacity = 0;
    loader.source = "YouJizzInfoView.qml";
    loader.item.goToVideo.connect(loadYouJizzVideoInfo);
    loader.item.playVideo.connect(loadPlaybackView);
    loader.item.search.connect(youjizzSearch);
    loader.item.setVideo(video);
    notificationArea.addTitle(qsTr("Video Info"));
    windowView.incrementCurrentIndex();
}
